(define-module (glicid packages linux)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module ((guix licenses)
                #:prefix license:)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system go)
  #:use-module (gnu packages backup)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages cryptsetup)
  #:use-module (gnu packages golang)
  #:use-module ((gnu packages linux)
                #:prefix gnu:)
  #:use-module (gnu packages linux) ;yes : redundant FIXIT
  #:use-module (gnu system uuid)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages python)
  #:use-module (gnu packages tls)
  #:use-module (glicid packages golang)
  #:use-module (glicid utils))

(define-public rdma-core-upstream-37.1
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "37.1")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "1hjwagf5x48vgshy5s01qjlzjr8kmxpflfcvh8pgj3zbj82zzxiz"))))))

(define-public rdma-core-upstream-38.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "38.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "043vybwx9kz4mbbmnj0jzkzsw02vzhkkjc5j3yjdiiqkmsgwr3cs"))))))

(define-public rdma-core-upstream-39.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "39.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "0y13px3qgyh3szywjhikw183y54iym9sa60aw0sf51p3kzgg1spn"))))))

(define-public rdma-core-upstream-41.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "41.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "0yshfxm9i9fi51mmnxbbv39hqlrc34jzmq6gl2b9f8hzlywdxdz0"))))))

(define-public rdma-core-upstream-42.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "42.0")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "03kclikv4k6rpsj6il131jjbnxyvdaiprc3wkmxn471crxsa9f9y"))))))

(define-public rdma-core-upstream-42.1
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream"))
    (version "42.1")
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/linux-rdma/rdma-core/releases/download/v"
                    version "/rdma-core-" version ".tar.gz"))
              (sha256
               (base32
                "02xjksnm71aak215f9262c2qbs77n4yc856ra6dlcfblciqk1cxp"))))))

(define local-rdma-core
  rdma-core-upstream-42.1)

(define-public rdma-core-latest
  (latest-version local-rdma-core gnu:rdma-core))

(define-public libfabric-upstream-1.17.0
  (package
    (inherit gnu:libfabric)
    (version "1.17.0")
    (name (string-append (package-name gnu:libfabric) "-upstream"))
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/ofiwg/libfabric/releases/download/v"
                    version "/libfabric-" version ".tar.bz2"))
              (sha256
               (base32
                "0pblwkgbnpf40is3isn47andkbm5j7dd8srx9lpwgh1nyrg0z72p"))))
    (inputs (modify-inputs (package-inputs gnu:libfabric)
              (prepend `(,util-linux "lib")
                       ;; uuid.h, numa.h
                       gnu:numactl)))))

(define local-libfabric
  libfabric-upstream-1.17.0)

(define-public libfabric-latest
  (latest-version local-libfabric gnu:libfabric))

(define-public libfabric-upstream-1.16.1
  (package
    (inherit local-libfabric)
    (version "1.16.1")
    (name (string-append (package-name gnu:libfabric) "-upstream"))
    (source (origin
              (method url-fetch)
              (uri (string-append
                    "https://github.com/ofiwg/libfabric/releases/download/v"
                    version "/libfabric-" version ".tar.bz2"))
              (sha256
               (base32
                "0gqr7765za14kalwws2brw8l6zw80iai0ggaljw99zls7z9r5yak"))))))

(define-public psm2-upstream-11.2.228
  (package
    (inherit gnu:psm2)
    (name "psm2-upstream")
    (version "11.2.228")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/cornelisnetworks/opa-psm2")
                    (commit (string-append "PSM2_" version))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1yymw4rkpdkzyi0lglagncjg1az2qmnq6f3lgrkvs6y77l9z6wrz"))))))

(define-public psm2-upstream-11.2.230
  (package
    (inherit gnu:psm2)
    (name "psm2-upstream")
    (version "11.2.230")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/cornelisnetworks/opa-psm2")
                    (commit (string-append "PSM2_" version))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1bm7ndhi8qzmd0plnggj2h52yb34bab4k38530nsnkmv9smwdivl"))))))

(define local-psm2
  psm2-upstream-11.2.230)

(define-public psm2-latest
  (latest-version local-psm2 gnu:psm2))

(define-public corefreq
  (package
    (inherit gnu:corefreq)
    (name "corefreq")
    (version "1.93.1")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/cyring/CoreFreq")
                    (commit version)))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "1crp1cmfcfd26j8rg29pl3lbkp135f17jr1686y0cb87v133kcq8"))))))
